
LotropadWindow = class( Turbine.UI.Window );
sSlot = 1; -- default selected slot
sBank = 1; -- default selected bank
activeColor = Turbine.UI.Color( 1, 1, 1); -- font color for active button
inactiveColor = Turbine.UI.Color( 0.8, 0.6, 0); -- font color for inactive button
Settings = { WindowPosition = { Left = "700", Top = "20", Width = "500", Height = "500", MiniWidth = "400", MiniHeight = "400" }, FontSize = "14", WindowOpacity = "0.9", WindowVisible = "yes", ToggleVisible = "yes", ToggleLeft =  tostring(Turbine.UI.Display.GetWidth()-55), ToggleTop = "270", MiniMode = false, DefaultBank = "1", DefaultNote = "1" }; -- default values

-- fix to prevent Vindar patch from messing up anything since it's not needed
LotropadLoad = Turbine.PluginData.Load;
LotropadSave = Turbine.PluginData.Save;

if (lang == "de" or lang == "fr") then
	if (Turbine.Engine.GetLocale() == "de" or Turbine.Engine.GetLocale() == "fr") then
		Settings.WindowOpacity = "0,9";
	end
end

Notes = {};
NoteDB = {};
for i = 1,10 do
	local target = "1_" .. i;
	NoteDB[target] = {Title = tostring(i), Text = "", ImageFile = ""};
end

Settings = LotropadLoad( Turbine.DataScope.Account , "LotropadSettings") or Settings;

function LotropadWindow:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self );
	
	-- Hide UI when F12 is pressed
	local hideUI = false;
	local wasVisible;
	self:SetWantsKeyEvents(true);
	self.KeyDown = function(sender, args)
		if (args.Action == 268435635) then
			if not hideUI then
				hideUI = true;
				if self:IsVisible() then
					wasVisible = true;
					self:SetVisible(false);
					if self.imgWindow then
						self.imgWindow:SetVisible(false);
					end
				else
					wasVisible = false;
				end
				toggleWindow:SetVisible(false);
			else
				hideUI = false;
				if wasVisible then
					self:SetVisible(true);			
				end
				if (Settings.ToggleVisible == "yes") then
					toggleWindow:SetVisible(true);
				end
			end
		end
	end
	
	
	Notes = LotropadLoad( Turbine.DataScope.Account , "LotropadData") or NoteDB;

	-- legacy fix
	if not (Settings.WindowVisible) then
		Settings.WindowVisible = "yes";
	end
	if not Settings.MiniMode then
		Settings.MiniMode = false;
	end
	if not Settings.DefaultNote then
		Settings.DefaultBank = "1";
		Settings.DefaultNote = "1";		
	end
	if not Settings.WindowPosition.MiniWidth then
		Settings.WindowPosition.MiniWidth = "400";
		Settings.WindowPosition.MiniHeight = "400";
	end
	
	
	-- check if old data base format
	if Notes[1] then
		for i = 1,10 do
			NoteDB["1_" .. i].Text = Notes[i].Text;
			NoteDB["1_" .. i].Title = Notes[i].Title;
			NoteDB["1_" .. i].ImageFile = Notes[i].ImageFile;
		end
		LotropadSave( Turbine.DataScope.Account, "LotropadData", NoteDB,
			function( result, message )
				if ( result ) then
					Turbine.Shell.WriteLine( "<rgb=#00FF00>" .. Strings["sh_upgrade"] .. "</rgb>");
				else
					Turbine.Shell.WriteLine( "<rgb=#FF0000>" .. Strings["sh_upgrade_fail"] .. " " .. message .. "</rgb>" );
				end
			end);		
	else
		NoteDB = Notes;
	end
	
	
	self:SetPosition( Settings.WindowPosition.Left, Settings.WindowPosition.Top );
	self:SetSize( Settings.WindowPosition.Width, Settings.WindowPosition.Height );
	
	bgColor = Turbine.UI.Color( 0, 0, 0);
	focusColor = Turbine.UI.Color(1, 0.15, 0.15, 0.15);
	
	--self:SetBackColor( bgColor );
	self:SetOpacity( Settings.WindowOpacity );
	self:SetZOrder(50);
	self:SetText("Lotropad");
	
	self.minWidth = 393;
	self.minHeight = 424;
	
	-- frame for note
	self.frame = Turbine.UI.Control();
	self.frame:SetParent( self );
	self.frame:SetPosition( 115, 37);
	self.frame:SetWidth( self:GetWidth() - 135 );
	self.frame:SetHeight( self:GetHeight() - 60 );
	self.frame:SetBackColor( focusColor );	
	
	-- label for the title text box
	self.titleLabel = Turbine.UI.Label();
	self.titleLabel:SetParent( self );
	self.titleLabel:SetPosition(120 , 45);
	self.titleLabel:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.titleLabel:SetText(Strings["ui_title"]);	
	
	-- text field for notes
	self.textInput = Turbine.UI.Lotro.TextBox();
	self.textInput:SetParent( self );
	self.textInput:SetVisible( true );
	self.textInput:SetMouseVisible( true );
	self.textInput:SetPosition(120 , 70);
	self.textInput:SetSize(self:GetWidth() - 145, self:GetHeight() - 100);	
	if (Settings.FontSize == "10") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana10 );
		elseif (Settings.FontSize == "12") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana12 );
		elseif (Settings.FontSize == "14") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana14 );
		elseif (Settings.FontSize == "16") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana16 );
		elseif (Settings.FontSize == "18") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana18 );
		elseif (Settings.FontSize == "20") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana20 );
		elseif (Settings.FontSize == "22") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana22 );
	end
	
	-- button for opening the settings menu
	self.configButton = Turbine.UI.Lotro.Button();
	self.configButton:SetParent( self );
	self.configButton:SetPosition( 20, 350 );
	self.configButton:SetWidth( 90 );
	self.configButton:SetText(Strings["ui_settings"]);
	
	-- button for opening the settings menu
	self.saveAllButton = Turbine.UI.Lotro.Button();
	self.saveAllButton:SetParent( self );
	self.saveAllButton:SetPosition( 20, 380 );
	self.saveAllButton:SetWidth( 90 );
	self.saveAllButton:SetText(Strings["ui_saveall"]);
	
	-- button separator
	self.separator = Turbine.UI.Control();
	self.separator:SetParent( self );
	self.separator:SetPosition( 30, 340 );
	self.separator:SetSize( 70, 3 );
	self.separator:SetBackColor( focusColor );	
	
	-- scrollbar for main text field
	self.textScroll = Turbine.UI.Lotro.ScrollBar();
	self.textScroll:SetParent( self );
	self.textScroll:SetOrientation( Turbine.UI.Orientation.Vertical );
	self.textScroll:SetPosition( self:GetWidth() - 17, 70 )
	self.textScroll:SetHeight( self.textInput:GetHeight() );
	self.textScroll:SetWidth( 10 );
	self.textScroll:SetValue( 0 ); 
	
	self.textInput:SetVerticalScrollBar( self.textScroll );

	-- text field for note title
	self.titleInput = Turbine.UI.Lotro.TextBox();
	self.titleInput:SetParent( self );
	self.titleInput:SetVisible( true );
	self.titleInput:SetPosition(160 , 43);
	self.titleInput:SetSize(100, 20);
	self.titleInput:SetMultiline( false );
	self.titleInput:SetFont(Turbine.UI.Lotro.Font.Verdana14);	

	-- load first note
	if Settings.DefaultNote then
		sSlot = tonumber(Settings.DefaultNote);
		sBank = tonumber(Settings.DefaultBank);
	end
	self.titleInput:SetText( NoteDB[sBank .. "_" .. sSlot].Title ); -- load default note title
	
	if (NoteDB[sBank .. "_" .. sSlot].Text ~= "") then 
		local cleanData = string.gsub(NoteDB[sBank .. "_" .. sSlot].Text, "\\n", "\n"); -- decode line breaks
		self.textInput:SetText( cleanData );
	end
	if (NoteDB[sBank .. "_" .. sSlot].ImageFile ~= "") then
		self.textInput:SetBackground( "Chiran/Lotropad/images/" .. NoteDB[sBank .. "_" .. sSlot].ImageFile );
	else
		self.textInput:SetBackground( "Chiran/Lotropad/bg.tga" );
	end
	
	-- button for saving note
	self.saveButton = Turbine.UI.Lotro.Button();
	self.saveButton:SetParent( self );
	self.saveButton:SetPosition(self:GetWidth() - 78, 43);
	self.saveButton:SetWidth( 55 );
	self.saveButton:SetText(Strings["ui_set"]);
	
	-- button for adding a background image
	self.imgButton = Turbine.UI.Lotro.Button();
	self.imgButton:SetParent( self );
	self.imgButton:SetPosition(267, 43);
	self.imgButton:SetWidth( 45 );
	self.imgButton:SetText(Strings["ui_img"]);
	
	-- control for focused button background
	self.focus = Turbine.UI.Control();
	self.focus:SetParent( self );
	self.focus:SetPosition( 17, 37);
	self.focus:SetWidth( 100 );
	self.focus:SetHeight( 30 );
	self.focus:SetBackColor( focusColor );
	self.focus:SetVisible( true );
	self.focus:SetTop( sSlot * 30 + 7 ); -- default focus
	
	-- create and initialize slot buttons
	self.slotButtons = {}
	
	for i = 1,10 do 
		self.slotButtons[i] = Turbine.UI.Lotro.Button();
		self.slotButtons[i]:SetParent( self );
		self.slotButtons[i]:SetPosition( 20, i * 30 + 12 );
		self.slotButtons[i]:SetWidth( 90 );
	
		if (i == 1) then
			self.slotButtons[i]:SetForeColor( activeColor );
			self.slotButtons[i]:SetFontStyle( Turbine.UI.FontStyle.Outline );
		else				
			self.slotButtons[i]:SetForeColor( inactiveColor );
			self.slotButtons[i]:SetFontStyle( Turbine.UI.FontStyle.None );			
		end
	
		if NoteDB[sBank .. "_" .. i] then
			self.slotButtons[i]:SetText( NoteDB[sBank .. "_" .. i].Title);
		else
			self.slotButtons[i]:SetText( i );
		end
	end
		
	-- actions for slot buttons
	self.slotButtons[1].MouseDown = function( sender, args )
		self:SaveNote( sSlot );
		sSlot = 1;		
		self:GetTextData( 1 );
		self:ActivateButton( 1 );		
	end
	
	self.slotButtons[2].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 2;
		self:GetTextData( 2 );
		self:ActivateButton( 2 );
	end
	
	self.slotButtons[3].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 3;
		self:GetTextData( 3 );
		self:ActivateButton( 3 );
	end

	self.slotButtons[4].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 4;
		self:GetTextData( 4 );
		self:ActivateButton( 4 );
	end
	
	self.slotButtons[5].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 5;
		self:GetTextData( 5 );
		self:ActivateButton( 5 );
	end
	
	self.slotButtons[6].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 6;
		self:GetTextData( 6 );
		self:ActivateButton( 6 );
	end
	
	self.slotButtons[7].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 7;
		self:GetTextData( 7 );
		self:ActivateButton( 7 );
	end
	
	self.slotButtons[8].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 8;
		self:GetTextData( 8 );
		self:ActivateButton( 8 );
	end
	
	self.slotButtons[9].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 9;
		self:GetTextData( 9 );
		self:ActivateButton( 9 );
	end
	
	self.slotButtons[10].MouseDown = function( sender, args )
		self:SaveNote( sSlot );	
		sSlot = 10;
		self:GetTextData( 10 );
		self:ActivateButton( 10 );
	end
	
	-- action for closing window and saving position
	self.Closed = function( sender, args )
		self:SaveAll( );
		Settings.WindowPosition.Left = self:GetLeft();
		Settings.WindowPosition.Top = self:GetTop();
		self:SetVisible( false );
	end
	
	-- window resize control, thanks to Dhor
	self.resizeCtrl = Turbine.UI.Control();
	self.resizeCtrl:SetParent(self);
	self.resizeCtrl:SetSize(20,20);		
	self.resizeCtrl:SetZOrder(200);
	self.resizeCtrl:SetPosition(self:GetWidth() - 20,self:GetHeight() - 20); 
                    
	self.resizeCtrl.MouseDown = function(sender,args)
		sender.dragStartX = args.X;
		sender.dragStartY = args.Y;
		sender.dragging = true;
	end
		
	self.resizeCtrl.MouseUp = function(sender,args)
		sender.dragging = false;
		if not Settings.MiniMode then
			Settings.WindowPosition.Width = self:GetWidth();
			Settings.WindowPosition.Height = self:GetHeight();
		else
			Settings.WindowPosition.MiniWidth = self:GetWidth();
			Settings.WindowPosition.MiniHeight = self:GetHeight();			
		end	
	end
					
	self.resizeCtrl.MouseMove = function(sender,args)
	  	local width, height = self:GetSize();
      
		if ( sender.dragging ) then
			-- Fix for text displacement when dragged too far left
			if ( width == self.minWidth) and (args.X < 0) then
				args.X = 0;
			end
			
			self:SetSize( width + ( args.X - sender.dragStartX ), 
						height + ( args.Y - sender.dragStartY ) );
									
			self.saveButton:SetPosition( self:GetWidth() - 78, 43);
			
			if not Settings.MiniMode then
				self.frame:SetSize( self:GetWidth() - 135, self:GetHeight() - 60 );
				self.textInput:SetSize( self:GetWidth() - 145, self:GetHeight() - 100);
			else
				self.frame:SetSize( self:GetWidth() - 35, self:GetHeight() - 60 );
				self.textInput:SetSize( self:GetWidth() - 45, self:GetHeight() - 72);				
			end
			self.textScroll:SetPosition( self:GetWidth() - 17, self.textInput:GetTop() );
			self.textScroll:SetHeight( self.textInput:GetHeight() );
			
			-- set different minimun width and height for minimode
			local mwMod;
			if Settings.MiniMode then 
				mwMod = 200;
				mhMod = 180;
			else
				mwMod = 0;
				mhMod = 0;
			end
			
			if (self:GetWidth() < (self.minWidth - mwMod)) then
				self:SetWidth( self.minWidth - mwMod);
				if not Settings.MiniMode then 
					self.textInput:SetWidth( self.minWidth - 145 - mwMod);
					self.frame:SetWidth( self.minWidth - 135 - mwMod);
				else
					self.textInput:SetWidth( self.minWidth - 45 - mwMod);
					self.frame:SetWidth( self.minWidth - 35 - mwMod);
				end
				self.saveButton:SetLeft( self.minWidth - 78 );			
				self.textScroll:SetLeft( self:GetWidth() - 17);
			end
			
			if (self:GetHeight() < self.minHeight - mhMod) then
				self:SetHeight(self.minHeight- mhMod);
				if not Settings.MiniMode then
					self.textInput:SetHeight( self.minHeight - 100 - mhMod);
					self.frame:SetHeight( self.minHeight - 60 );
					self.textScroll:SetHeight( self.minHeight - 100 - mhMod );
				else
					self.textInput:SetHeight( self.minHeight - 72 - mhMod);
					self.frame:SetHeight( self.minHeight - 60 - mhMod);
				end
				self.textScroll:SetHeight( self.textInput:GetHeight() );	
			end
		  
			sender:SetPosition( self:GetWidth() - sender:GetWidth(), self:GetHeight() - sender:GetHeight() );
		end
	end 
	
	-- Set last state
	if Settings.MiniMode then
		self:ToggleMinimode(1);
	end	
	
					
	-- load note to text field
	function self:GetTextData( slot )
		if NoteDB[sBank .. "_" .. slot] then
			self.titleInput:SetText( NoteDB[sBank .. "_" .. slot].Title );
			local cleanData = string.gsub(NoteDB[sBank .. "_" .. slot].Text, "\\n", "\n"); -- decode line breaks
			self.textInput:SetText( cleanData );			
			--self.textInput:SetText( NoteDB[sBank .. "_" .. slot].Text );
			if (NoteDB[sBank .. "_" .. slot].ImageFile ~= "") then
				self.textInput:SetBackground( "Chiran/Lotropad/images/" .. NoteDB[sBank .. "_" .. slot].ImageFile );
			else
				self.textInput:SetBackground( "Chiran/Lotropad/bg.tga" );
			end			
		else
			self.titleInput:SetText( "" );		
			self.textInput:SetText( "" );
		end
	end
	
	-- set button colors
	function self:ActivateButton( slot )		
		self.focus:SetTop( slot * 30 + 7 );
		for i = 1,10 do 
			if (i == slot) then
				self.slotButtons[i]:SetForeColor( activeColor );				
			else				
				self.slotButtons[i]:SetForeColor( inactiveColor );
			end
		end
	end
	
	function self:SaveNote ( slot )
		if not NoteDB[sBank .. "_" .. slot] then
			NoteDB[sBank .. "_" .. slot] = { };
			NoteDB[sBank .. "_" .. slot].Title = "";
			NoteDB[sBank .. "_" .. slot].Text = "";
			NoteDB[sBank .. "_" .. slot].ImageFile = "";
		end
			
		NoteDB[sBank .. "_" .. slot].Title = self.titleInput:GetText();
		local cleanData = string.gsub(self.textInput:GetText(), "\n", "\\n"); -- encode line breaks
		NoteDB[sBank .. "_" .. slot].Text = cleanData;
		self.slotButtons[slot]:SetText( NoteDB[sBank .. "_" .. slot].Title );			
	end
	
	-- settings menu 
	self.configButton.MouseClick = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Left) then
			local settingsMenu = Turbine.UI.ContextMenu();
			local fontSizeMenu = Turbine.UI.MenuItem( Strings["set_fontsize"] );
			local fontSizeItems = fontSizeMenu:GetItems();
			local opacityMenu = Turbine.UI.MenuItem( Strings["set_opacity"] );
			local opacityItems = opacityMenu:GetItems();
			local i;
			
			-- items for selecting font size of the main text field
			for i = 10, 22, 2 do 
				local fontSizeItem = Turbine.UI.MenuItem( tostring( i ) );
				if ( Settings.FontSize == tostring( i ) ) then
					fontSizeItem:SetChecked( true );
				end
				fontSizeItem.Click = function( sender, args )					
					self:ChangeFont( sender:GetText() );
				end  
				fontSizeItems:Add( fontSizeItem );
			end
			
			--items for setting window opacity
			for i = 0.1, 1.0, 0.1 do
				local opacityItem = Turbine.UI.MenuItem( i );
				if ( Settings.WindowOpacity == tostring(i) ) then
					opacityItem:SetChecked( true );
				end
				opacityItem.Click = function( sender, args )					
					self:ChangeOpacity( sender:GetText() );
				end  
				opacityItems:Add( opacityItem );
			end
			
			local visibilityItem = Turbine.UI.MenuItem( Strings["set_windowvis"] );
			if (Settings.WindowVisible == "yes") then
				visibilityItem:SetChecked( true );
			end
			visibilityItem.Click = function( sender, args )				
				self:ChangeVisibility();
			end			
			local toggleItem = Turbine.UI.MenuItem( Strings["set_iconvis"] );
			if (Settings.ToggleVisible == "yes") then
				toggleItem:SetChecked( true );
			end			
			toggleItem.Click = function( sender, args )					
				self:ChangeToggleVisibility();
			end			
			
			local settingsMenuItems = settingsMenu:GetItems();
			settingsMenuItems:Add( fontSizeMenu );
			settingsMenuItems:Add( opacityMenu );
			settingsMenuItems:Add( visibilityItem );
			settingsMenuItems:Add( toggleItem );
			settingsMenu:ShowMenu();						
		end
	end
	-- action for changing font size
	function self:ChangeFont( newSize )		
		if (newSize == "10") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana10 );
			elseif (newSize == "12") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana12 );
			elseif (newSize == "14") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana14 );
			elseif (newSize == "16") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana16 );
			elseif (newSize == "18") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana18 );
			elseif (newSize == "20") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana20 );
			elseif (newSize == "22") then self.textInput:SetFont( Turbine.UI.Lotro.Font.Verdana22 );
		end
		Settings.FontSize = newSize;
	end
	
	-- action for changing window opacity
	function self:ChangeOpacity( newOpacity )
		self:SetOpacity( newOpacity );
		Settings.WindowOpacity = newOpacity;
	end
	
	-- action for changing window visibility
	function self:ChangeVisibility()
		if (Settings.WindowVisible == "yes") then
			Settings.WindowVisible = "no";			
		else
			Settings.WindowVisible = "yes";
		end
	end
	
	function self:ChangeToggleVisibility()
		if (Settings.ToggleVisible == "yes") then
			Settings.ToggleVisible = "no";
			toggleWindow:SetVisible(false);
		else
			Settings.ToggleVisible = "yes";
			toggleWindow:SetVisible(true);
		end
	end

	-- action for save button
	self.saveButton.MouseDown = function( sender, args )
		self:SaveNote( sSlot );					
	end
	
	self.saveAllButton.MouseDown = function( sender, args )
		self:SaveAll( );							
	end
	
	self.imgButton.MouseClick = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Left) then
			self.imgWindow = Turbine.UI.Lotro.Window();
			self.imgWindow:SetVisible(true);
			self.imgWindow:SetPosition( self:GetLeft() + 130, self:GetTop() + 100 );
			self.imgWindow:SetZOrder(60);
			self.imgWindow:SetSize( 250, 155);
			self.imgWindow:SetText(Strings["ui_setimg"]);			
			
			self.imgWindow.imgLabel = Turbine.UI.Label();
			self.imgWindow.imgLabel:SetParent( self.imgWindow );
			self.imgWindow.imgLabel:SetPosition(20 , 40);
			self.imgWindow.imgLabel:SetWidth( 200 );
			self.imgWindow.imgLabel:SetFont(Turbine.UI.Lotro.Font.Verdana14);
			self.imgWindow.imgLabel:SetText(Strings["ui_imghelp"]);
			
			self.imgWindow.imgInput = Turbine.UI.Lotro.TextBox();
			self.imgWindow.imgInput:SetParent( self.imgWindow );
			self.imgWindow.imgInput:SetMouseVisible( true );
			self.imgWindow.imgInput:SetPosition(20 , 80);
			self.imgWindow.imgInput:SetFont(Turbine.UI.Lotro.Font.Verdana14);
			self.imgWindow.imgInput:SetSize(210, 20);
			self.imgWindow.imgInput:SetMultiline( false );
			
			self.imgWindow.clearButton = Turbine.UI.Lotro.Button();
			self.imgWindow.clearButton:SetParent( self.imgWindow );
			self.imgWindow.clearButton:SetPosition( 20 , 110);
			self.imgWindow.clearButton:SetWidth( 90 );
			self.imgWindow.clearButton:SetText(Strings["ui_imgclear"]);
			
			self.imgWindow.setButton = Turbine.UI.Lotro.Button();
			self.imgWindow.setButton:SetParent( self.imgWindow );
			self.imgWindow.setButton:SetPosition( 152 , 110);
			self.imgWindow.setButton:SetWidth( 80 );
			self.imgWindow.setButton:SetText(Strings["ui_setimg"]);
			
			self.imgWindow.imgInput:SetText( NoteDB[sBank .. "_" .. sSlot].ImageFile );
			
			self.imgWindow.clearButton.MouseClick = function( sender, args )
				if(args.Button == Turbine.UI.MouseButton.Left) then
					NoteDB[sBank .. "_" .. sSlot].ImageFile = "";
					self.textInput:SetBackground( "Chiran/Lotropad/bg.tga" );
					self.imgWindow:Close();
				end
			end
			
			self.imgWindow.setButton.MouseClick = function( sender, args )
				if(args.Button == Turbine.UI.MouseButton.Left) then
					NoteDB[sBank .. "_" .. sSlot].ImageFile = self.imgWindow.imgInput:GetText();
					self.textInput:SetBackground( "Chiran/Lotropad/images/" .. NoteDB[sBank .. "_" .. sSlot].ImageFile );													
					self.imgWindow:Close();
				end
			end
		end
	end
	
	function Turbine.Plugin:Unload(sender, args)
		--self:SaveAll( ); -- doesn't work
	end
end

function LotropadWindow:ToggleMinimode(force)
	if not Settings.MiniMode or (force == 1) then
		Settings.MiniMode = true;
		if (force ~= 1) then
			self:SetLeft(self:GetLeft() + 100);
		end
		self:SetWidth(Settings.WindowPosition.MiniWidth);
		self:SetHeight(Settings.WindowPosition.MiniHeight);
		self.titleLabel:SetVisible(false);
		self.saveAllButton:SetVisible(false);
		self.configButton:SetVisible(false);
		self.separator:SetVisible(false);
		self.focus:SetVisible(false);
		self.titleInput:SetVisible(false);
		self.saveButton:SetVisible(false);			
		self.imgButton:SetVisible(false);
		for i = 1,10 do 
			self.slotButtons[i]:SetVisible(false);	
		end
		self.frame:SetPosition( 15, 37);
		self.frame:SetSize(self:GetWidth() - 35, self:GetHeight() - 60);		
		self.textInput:SetPosition(20 , 42);
		self.textInput:SetSize(self:GetWidth() - 45, self:GetHeight() - 72);
		self.resizeCtrl:SetPosition(self:GetWidth() - 20,self:GetHeight() - 20); 	
		self.textScroll:SetPosition( self:GetWidth() - 17, 42 )
		self.textScroll:SetHeight( self.textInput:GetHeight() );
		self:SetText(NoteDB[sBank .. "_" .. sSlot].Title);
	else
		Settings.MiniMode = false;
		self:SetLeft(self:GetLeft() - 100);
		self:SetWidth(Settings.WindowPosition.Width);
		self:SetHeight(Settings.WindowPosition.Height);
		self.titleLabel:SetVisible(true);
		self.saveAllButton:SetVisible(true);
		self.configButton:SetVisible(true);
		self.separator:SetVisible(true);
		self.focus:SetVisible(true);
		self.titleInput:SetVisible(true);
		self.saveButton:SetVisible(true);
		self.imgButton:SetVisible(true);
		for i = 1,10 do 
			self.slotButtons[i]:SetVisible(true);	
		end
		self.frame:SetPosition( 115, 37);
		self.frame:SetWidth( self:GetWidth() - 135 );			
		self.textInput:SetPosition(120 , 70);
		self.textInput:SetSize(self:GetWidth() - 145, self:GetHeight() - 100);	
		self.resizeCtrl:SetPosition(self:GetWidth() - 20,self:GetHeight() - 20); 
		self.textScroll:SetPosition( self:GetWidth() - 17, 70 )
		self.textScroll:SetHeight( self.textInput:GetHeight() );
		self.saveButton:SetPosition(self:GetWidth() - 78, 43);
		self:SetText("Lotropad");		
	end
end

function LotropadWindow:SaveAll()	
	-- save default note
	Settings.DefaultNote = sSlot;
	Settings.DefaultBank = sBank;

	-- save latest window position						
	Settings.WindowPosition.Left = tostring(self:GetLeft());
	Settings.WindowPosition.Top = tostring(self:GetTop());
	
	self:SaveNote( sSlot ); -- Enter current note to database
	Turbine.Shell.WriteLine( "<rgb=#00FF00>".. Strings["sh_saving"] .."</rgb>");
	
	LotropadSave( Turbine.DataScope.Account, "LotropadSettings", Settings,
		function( result, message )
			if ( result ) then
				Turbine.Shell.WriteLine( "<rgb=#00FF00>".. Strings["sh_saved"] .. "</rgb>");
			else
				Turbine.Shell.WriteLine( "<rgb=#FF0000>" .. Strings["sh_notsaved"] .. " " .. message .. "</rgb>" );
			end
		end);
		
	LotropadSave( Turbine.DataScope.Account, "LotropadData", NoteDB,
		function( result, message )
			if ( result ) then
				Turbine.Shell.WriteLine( "<rgb=#00FF00>Lotropad data saved.</rgb>");
			else
				Turbine.Shell.WriteLine( "<rgb=#FF0000>Lotropad failed to save the data: " .. message .. "</rgb>" );
			end
		end);
end
